# This file is part of P^nMPI.
#
# Copyright (c)
#  2008-2018 Lawrence Livermore National Laboratories, United States of America
#  2011-2016 ZIH, Technische Universitaet Dresden, Federal Republic of Germany
#  2013-2018 RWTH Aachen University, Federal Republic of Germany
#
#
# P^nMPI is free software; you can redistribute it and/or modify it under the
# terms of the GNU Lesser General Public License as published by the Free
# Software Foundation version 2.1 dated February 1999.
#
# P^nMPI is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
# details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with P^nMPI; if not, write to the
#
#   Free Software Foundation, Inc.
#   51 Franklin St, Fifth Floor
#   Boston, MA 02110, USA
#
#
# Written by Martin Schulz, schulzm@llnl.gov.
#
# LLNL-CODE-402774

# Search for dependencies required by PnMPI. These are required for compiling
# code which uses PnMPI.
#
# NOTE: Other packages need to be searched before this package is initialized,
#       as other packages may overwrite the PACKAGE_PREFIX_DIR of this package.
find_package(MPI REQUIRED)



####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was PnMPIConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib64/openmpi3" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr/lib64/openmpi3")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################


# Basic PnMPI configuration.
#
# The following variables store the basic PnMPI configuration and may be used to
# check if basic conditions are met or where to find dependencies.

set(PnMPI_VERSION       "v1.8"       CACHE INTERNAL "")
set(PnMPI_VERSION_MAJOR "1" CACHE INTERNAL "")
set(PnMPI_VERSION_MINOR "8" CACHE INTERNAL "")
set(PnMPI_VERSION_PATCH "0" CACHE INTERNAL "")
set(PnMPI_VERSION_TWEAK "0" CACHE INTERNAL "")


# Set dependent PnMPI configuration.
#
# Some of PnMPI's configuration variables depend on how PnMPI is included into
# other projects (via find_package() or add_subdirectory()). These variables
# will be set depending on the include mode and cached later if necessary.
if (NOT PnMPI_IS_SUBPROJECT)
  set_and_check(PnMPI_INCLUDE_DIR "/usr/lib64/openmpi3/include")
  set_and_check(PnMPI_MODULES_DIR "/usr/lib64/openmpi3/lib/pnmpi-modules")
else ()
  include(PnMPI_headers)
  set(PnMPI_INCLUDE_DIR "${PNMPI_HEADER_DIR}"
                        "/builddir/build/BUILD/PnMPI-v1.8/src/pnmpi"
                        "/builddir/build/BUILD/PnMPI-v1.8/openmpi3")
endif ()

set(PnMPI_INCLUDE_PATH
    ${PnMPI_INCLUDE_DIR}
    ${MPI_C_INCLUDE_PATH}
  CACHE PATH "PnMPI include paths")
set(PnMPI_MODULES_PATH ${PnMPI_MODULES_DIR} CACHE PATH "PnMPI modules location")


# Component configuration.
#
# PnMPI has optional components, which will be configured in the following
# section. find_package() provides capabilities to check whether a module has a
# specific component or not.

set(PnMPI_PnMPIze_FOUND ON CACHE INTERNAL "")


# Handle arguments of 'find_package()'.
#
# If 'find_package()' is used to find PnMPI, check its arguments and required
# components.
include(FindPackageHandleStandardArgs)
find_package_handle_standard_args(PnMPI
  REQUIRED_VARS
    PnMPI_VERSION
    PnMPI_INCLUDE_PATH
    PnMPI_MODULES_PATH
  HANDLE_COMPONENTS
)

mark_as_advanced(
  PnMPI_INCLUDE_PATH
  PnMPI_MODULES_PATH
)


# Include PnMPI targets as imported targets.
#
# By including the following files, PnMPI targets will be imported to be used by
# the project including this file.
#
# NOTE: This is not necessary, if PnMPI is included via 'add_subdirectory()',
#       as PnMPI's native targets are available.
if (NOT PnMPI_IS_SUBPROJECT)
  include(${PACKAGE_PREFIX_DIR}/pnmpi-libs.cmake)
  include(${PACKAGE_PREFIX_DIR}/pnmpi-patch.cmake)
  if (PnMPI_PnMPIze_FOUND)
    include(${PACKAGE_PREFIX_DIR}/pnmpize.cmake)
  endif ()
endif ()

# Set aliases for PnMPI libraries and executables.
#
# These variables may be used to link against the PnMPI libraries. However, the
# path to the library itself is not stored in these variables, but the names of
# the targets imported above.

# Basic PnMPI library. Default for most people.
set(PnMPI_LIBRARIES pnmpi CACHE INTERNAL "")

# Language-specific PnMPI library targets to link against.
set(PnMPI_C_LIBRARIES              pnmpi         CACHE INTERNAL "")
set(PnMPI_C_STATIC_LIBRARIES       pnmpi_static  CACHE INTERNAL "")

set(PnMPI_CXX_LIBRARIES            pnmpi         CACHE INTERNAL "")
set(PnMPI_CXX_STATIC_LIBRARIES     pnmpi_static  CACHE INTERNAL "")

set(PnMPI_Fortran_LIBRARIES        pnmpif        CACHE INTERNAL "")
set(PnMPI_Fortran_STATIC_LIBRARIES pnmpif_static CACHE INTERNAL "")

# PnMPI specific binaries.
set(PnMPI_PATCHER pnmpi-patch CACHE INTERNAL "")
if (PnMPI_PnMPIze_FOUND)
  set(PnMPI_PnMPIze pnmpize CACHE INTERNAL "")
endif ()


# Include PnMPI specific CMake functions.
#
# PnMPI uses additional CMake functions to easily add targets for PnMPI modules.
# These will be installed along with the PnMPI configuration.
if (NOT PnMPI_IS_SUBPROJECT)
  include(${PACKAGE_PREFIX_DIR}/PnMPI_modules.cmake)
else ()
  include(PnMPI_modules)
endif ()

# Wrapper for pnmpi_add_pmpi_module
#
# The PnMPI module add function implements a new API. This function maps the new
# function to the legacy API, so code using the PnMPI module doesn't get broken.
#
# NOTE: This function is DEPRECATED. New code should use the new API, as this
#       function will be removed in future commits.
function (add_pnmpi_module)
  pnmpi_add_pmpi_module(${ARGV})
endfunction ()


# Include configuration of PnMPI dependencies.
#
# PnMPI may be build with optional dependencies. The following variables store
# the used configuration, so projects know how PnMPI was build and how to access
# its dependencies.

# These variables allow client libraries to use the same adept_utils as PnMPI
set(PnMPI_USE_adept_utils           )
set(adept_utils_DIR	"adept_utils_DIR-NOTFOUND")
if (PnMPI_USE_adept_utils)
  find_package(adept_utils)
endif()

# These variables allow client libraries to use the same BFD library as PnMPI
set(PnMPI_USE_BFD                  )
set(PnMPI_BFD_INCLUDE_PATH         /usr/include)
set(PnMPI_BFD_LIBRARIES            /lib64/libbfd.so)
set(PnMPI_IBERTY_INCLUDE_PATH      /usr/include)
set(PnMPI_IBERTY_LIBRARIES         /lib64/libiberty.a)
